/*******************************************************************************
* File Name: main.c
* Version 1.0
*
* Description:
* This c file contains the main function for Capsense application using FTMF board 
* in CY3270/71 Kit using I2C as Communication.
*
* Note:
*
********************************************************************************
* Copyright (2011), Cypress Semiconductor Corporation.
********************************************************************************
* This software is owned by Cypress Semiconductor Corporation (Cypress) and is
* protected by and subject to worldwide patent protection (United States and
* foreign), United States copyright laws and international treaty provisions.
* Cypress hereby grants to licensee a personal, non-exclusive, non-transferable
* license to copy, use, modify, create derivative works of, and compile the
* Cypress Source Code and derivative works for the sole purpose of creating
* custom software in support of licensee product to be used only in conjunction
* with a Cypress integrated circuit as specified in the applicable agreement.
* Any reproduction, modification, translation, compilation, or representation of
* this software except as specified above is prohibited without the express
* written permission of Cypress.
*
* Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, WITH
* REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
* Cypress reserves the right to make changes without further notice to the
* materials described herein. Cypress does not assume any liability arising out
* of the application or use of any product or circuit described herein. Cypress
* does not authorize its products for use as critical components in life-support
* systems where a malfunction or failure may reasonably be expected to result in
* significant injury to the user. The inclusion of Cypress' product in a life-
* support systems application implies that the manufacturer assumes all risk of
* such use and in doing so indemnifies Cypress against all charges. Use may be
* limited by and subject to the applicable Cypress software license agreement.
*******************************************************************************/

/******************************************************************************
                                THEROY OF OPERATION
* This project demonstrates the use of Capsense Slider Sensors.
* The firmware supports 3 LEDs, a CapSense linear slider
* The "main" function completes the initialization of I2C Slave and Capsense
* component.
* After initialization of the User Modules, the "main" enters into a loop
* which consists of,
* "Scanning all sensors"
* If the value returned from Centroid position is greater than 0 and less than 33 
* Blue LED is ON
* If the value returned from Centroid position is greater than or equal to 33 and less than 66 
* Green LED is ON
* If the value returned from Centroid position is greater than or equal to 66 and less than 99 
* Red LED is ON
* "Storing the capsense data for all the sensors in the I2C registers.
* Hardware resources used for this project: PC Hub, Multifunction expansion card and RF card.
* PSoC Designer Version: 5.1 SP1.1 (Build:2110)
*******************************************************************************/

/*----------------------------------------------------------------------------
 C main line
---------------------------------------------------------------------------- */

#include <m8c.h>        /* part specific constants and macros */
#include "PSoCAPI.h"    /* PSoC API definitions for all User Modules */
#define POS 		1
#define BUFSIZE		1
#define RWBOUNDARY	1

struct I2C_Regs 
{ 
int Status;
} Data_Regs;

void main(void)
{
	 EzI2Cs_SetRamBuffer(sizeof(Data_Regs), RWBOUNDARY, (BYTE *) &Data_Regs);   /* Setting RAM Buffer */
	 M8C_EnableGInt ;   /* Enabling the Global Interrupts */

	CSD_Start();   /*Start CSD Module */
	CSD_ScanAllSensors();   /* Scan all the available sensors */
	CSD_InitializeBaselines() ;   /* Initialise base line for the sensors */
	CSD_SetDefaultFingerThresholds();
	LED_BLUE_Start();
	LED_GREEN_Start();
	LED_RED_Start();
	EzI2Cs_Start();   /* Turn on I2C */
	
	while(1) /*Infinite loop */
	{
		CSD_ScanAllSensors();  /*Scan all sensors in array (buttons and sliders) */
		CSD_UpdateAllBaselines();
				LED_RED_Off();
				LED_GREEN_Off();
				LED_BLUE_Off();
				Data_Regs.Status=0;
		if(CSD_bIsAnySensorActive())  /* is any sensor active */
		{
			Data_Regs.Status = CSD_wGetCentroidPos(POS);  /*Get the centroid position for the system	*/
			if(Data_Regs.Status < 33 && Data_Regs.Status >0) /*If the value returned from Centroid position is 
			                               greater than 0 and less than or equal to 33 */
			{
				CSD_UpdateAllBaselines(); /*Update base line for slider touch if  
				                           centroid position is less than 33 */
				LED_BLUE_On();
			}
			else if(Data_Regs.Status < 66 && Data_Regs.Status >=33)  /*If the value returned from Centroid position is 
			                                      greater than 33 and less than or equal to 66 */

			{
				CSD_UpdateAllBaselines();   /*Update base line for slider touch if
			                                centroid position is less than 66 */						
				LED_GREEN_On();
			}
			else if(Data_Regs.Status < 99 && Data_Regs.Status >=66)  /*If the value returned from Centroid position is
			                                      greater than 66 and less than or equal to 99 */
			{
				CSD_UpdateAllBaselines();  /*Update base line for slider touch if 
			                               centroid position is less than 99 */
				LED_RED_On();
			}
		}
	}
}
